@@ -82,7 +82,7 @@ static void
 usage(const struct cmdinfo *cip, const char *value)
 {
 	printf(_(
-"Usage: %s [<option> ...] <command>\n"
+"Usage: %s [<option>...] <command>\n"
 "\n"), dpkg_get_progname());
 
 	printf(_(
@@ -133,7 +133,7 @@ opt_rename_setup(void)
 }
 
 struct file {
-	const char *name;
+	char *name;
 	enum {
 		FILE_STAT_INVALID,
 		FILE_STAT_VALID,
@@ -155,6 +155,12 @@ file_init(struct file *f, const char *filename)
 	f->stat_state = FILE_STAT_INVALID;
 }
 
+static void
+file_destroy(struct file *f)
+{
+	free(f->name);
+}
+
 static void
 file_stat(struct file *f)
 {
@@ -512,6 +518,10 @@ diversion_add(const char *const *argv)
 			if (opt_verbose > 0)
 				printf(_("Leaving '%s'\n"),
 				       diversion_describe(fnn_from->divert));
+
+			file_destroy(&file_from);
+			file_destroy(&file_to);
+
 			return 0;
 		}
 
@@ -558,6 +568,9 @@ diversion_add(const char *const *argv)
 			file_rename(&file_from, &file_to);
 	}
 
+	file_destroy(&file_from);
+	file_destroy(&file_to);
+
 	return 0;
 }
 
@@ -669,6 +682,9 @@ diversion_remove(const char *const *argv)
 	if (!opt_test)
 		divertdb_write();
 
+	file_destroy(&file_from);
+	file_destroy(&file_to);
+
 	return 0;
 }
 
@@ -847,7 +863,6 @@ main(int argc, const char * const *argv)
 		setaction(&cmdinfo_add, NULL);
 
 	modstatdb_open(msdbrw_readonly);
-	fsys_hash_init();
 	ensure_diversions();
 
 	ret = cipaction->action(argv);
