@@ -205,6 +205,11 @@ static const struct forceinfo {
 		FORCE_REMOVE_REINSTREQ,
 		FORCETYPE_DAMAGE,
 		N_("Remove packages which require installation"),
+	}, {
+		"remove-protected",
+		FORCE_REMOVE_PROTECTED,
+		FORCETYPE_DAMAGE,
+		N_("Remove a protected package"),
 	}, {
 		"remove-essential",
 		FORCE_REMOVE_ESSENTIAL,
