@@ -585,7 +585,7 @@ showpackages(const char *const *argv)
 
   if (!*argv) {
     if (fmt_needs_db_fsys)
-      ensure_allinstfiles_available();
+      ensure_allinstfiles_available_quiet();
     for (i = 0; i < array.n_pkgs; i++) {
       pkg = array.pkgs[i];
       if (pkg->status == PKG_STAT_NOTINSTALLED)
@@ -786,7 +786,7 @@ static void DPKG_ATTR_NORET
 usage(const struct cmdinfo *ci, const char *value)
 {
   printf(_(
-"Usage: %s [<option> ...] <command>\n"
+"Usage: %s [<option>...] <command>\n"
 "\n"), DPKGQUERY);
 
   printf(_(
@@ -813,6 +813,7 @@ usage(const struct cmdinfo *ci, const char *value)
 "Options:\n"
 "  --admindir=<directory>           Use <directory> instead of %s.\n"
 "  --load-avail                     Use available file on --show and --list.\n"
+"  --no-pager                       Disables the use of any pager.\n"
 "  -f|--showformat=<format>         Use alternative format for --show.\n"
 "\n"), ADMINDIR);
 
@@ -870,8 +871,6 @@ int main(int argc, const char *const *argv) {
 
   if (!cipaction) badusage(_("need an action option"));
 
-  fsys_hash_init();
-
   ret = cipaction->action(argv);
 
   dpkg_program_done();
