@@ -63,8 +63,8 @@ static void DPKG_ATTR_NORET
 usage(const struct cmdinfo *ci, const char *value)
 {
 	printf(_(
-"Usage: %s [<options> ...] <trigger-name>\n"
-"       %s [<options> ...] <command>\n"
+"Usage: %s [<option>...] <trigger-name>\n"
+"       %s [<option>...] <command>\n"
 "\n"), dpkg_get_progname(), dpkg_get_progname());
 
 	printf(_(
@@ -229,8 +229,6 @@ main(int argc, const char *const *argv)
 		badusage(_("illegal awaited package name '%.250s': %.250s"),
 		         bypackage, badname);
 
-	fsys_hash_init();
-
 	activate = argv[0];
 	badname = trig_name_is_illegal(activate);
 	if (badname)
